@@ -5,7 +5,7 @@ from random import sample
 import click
 from vapoursynth import RGB24, VideoNode, core
 
-from .util.source import source
+from encode_utils_cli.util.source import source
 
 
 @click.command()
@@ -19,12 +19,12 @@ from .util.source import source
     "-d",
     "--out-dir",
     type=click.Path(file_okay=False, path_type=Path),
-    help="Custom out dir",
+    help="Custom out dir.",
 )
-@click.option("-f", "--frames", type=str, help="Frames")
-@click.option("-o", "--offset", type=int, default=0, help="Offset for clip")
-@click.option("-c", "--crop", type=int, default=0, help="CropRel args")
-@click.option("-p", "--drop-prop", is_flag=True, help="Delete frame prop")
+@click.option("-f", "--frames", type=str, help="Frames. Format: '1 2 3'.")
+@click.option("-o", "--offset", type=int, default=0, help="Offset for clip.")
+@click.option("-c", "--crop", type=int, default=0, help="CropRel args.")
+@click.option("-p", "--drop-prop", is_flag=True, help="Delete frame prop.")
 def vs_screens(
     vids: tuple[Path],
     out_dir: Path,
@@ -64,9 +64,7 @@ def open_clip(video: Path, drop_prop: bool, offset: int, crop: int) -> VideoNode
             .std.Setframe_prop(prop="_Transfer", delete=True)
             .std.Setframe_prop(prop="_Primaries", delete=True)
         )
-    clip = clip.resize.Spline36(
-        format=RGB24, matrix_in_s="709" if clip.height >= 576 else "601"
-    )
+    clip = clip.resize.Spline36(format=RGB24, matrix_in_s="709" if clip.height >= 576 else "601")
     if offset:
         clip = clip.std.Trim(offset, clip.num_frames - 1)
     if crop:
